==> stam_1.4.0.tar.gz: stam/man/stam.writeHTML.Rd <==
\name{stam.writeHTML}
\alias{stam.writeHTML}
\title{Write StAM Output in HTML}
\description{
  Write HTML output for various pieces of a structured analysis of microarray data for 
  further interactive exploration.
}
\usage{
stam.writeHTML(x, title = NULL, align = "left", 
               outfile = "index.html", nonodes = FALSE, ...)
}
\arguments{
  \item{x}{the piece of the analysis for which HTML is to be generated. It may be of any 
    of the following classes: \code{stamNode}, \code{stamNet}, \code{stamCV}, 
    \code{stamFit}, \code{stamPrediction} or \code{stamEval}}
  \item{title}{the title to be used on the generated main page. A default is generated 
    according to a few important parameters of \code{x}}
  \item{align}{alignment of the tatle (left, right, center)}
  \item{outfile}{the file where to store the generated HTML code unless \code{x} is of 
    class \code{stamEval}. In the latter case, \code{outfile} is a directory where the 
    the collection of files is stored. }
  \item{nonodes}{whether to generate (poxxibly lengthy) output for all nodes}
  \item{\dots}{further arguments passed to \code{writeHTML} calls.}
}
\details{
  Use this function to generate HTML pages for further investigation of StAM results. The 
  pages are interlinked and contain links to external resources such as the Gene Ontology 
  and the Affymetrix website. Clickable maps are generated for the illustration of the 
  model fit as well as the molecular symptoms image.
}
\author{Claudio Lottaz}
\examples{
data(golubTrain.cv)
data(golubTrain.fit)

stam.writeHTML(golubTrain.cv)
stam.writeHTML(golubTrain.fit, nonodes=TRUE)
}
\keyword{hplot}

==> stam_1.6.0.tar.gz: stam/man/stam.writeHTML.Rd <==
\name{stam.writeHTML}
\alias{stam.writeHTML}
\title{Write StAM Output in HTML}
\description{
  Write HTML output for various pieces of a structured analysis of microarray data for 
  further interactive exploration.
}
\usage{
stam.writeHTML(x, title = NULL, align = "left", 
               outfile = "index.html", nonodes = FALSE, ...)
}
\arguments{
  \item{x}{the piece of the analysis for which HTML is to be generated. It may be of any 
    of the following classes: \code{stamNode}, \code{stamNet}, \code{stamCV}, 
    \code{stamFit}, \code{stamPrediction} or \code{stamEval}}
  \item{title}{the title to be used on the generated main page. A default is generated 
    according to a few important parameters of \code{x}}
  \item{align}{alignment of the tatle (left, right, center)}
  \item{outfile}{the file where to store the generated HTML code unless \code{x} is of 
    class \code{stamEval}. In the latter case, \code{outfile} is a directory where the 
    the collection of files is stored. }
  \item{nonodes}{whether to generate (possibly lengthy) output for all nodes}
  \item{\dots}{further arguments passed to \code{writeHTML} calls.}
}
\details{
  Use this function to generate HTML pages for further investigation of StAM results. The 
  pages are interlinked and contain links to external resources such as the Gene Ontology 
  and the Affymetrix website. Clickable maps are generated for the illustration of the 
  model fit as well as the molecular symptoms image.
}
\author{Claudio Lottaz}
\examples{
data(golubTrain.cv)
data(golubTrain.fit)

stam.writeHTML(golubTrain.cv)
stam.writeHTML(golubTrain.fit, nonodes=TRUE)
}
\keyword{hplot}
